| TaskUnsupervised | R Documentation |
This is the abstract base class for unsupervised tasks such as cluster tasks in mlr3cluster and mlr3spatial.
Task -> TaskUnsupervised
TaskUnsupervised$new()Creates a new instance of this R6 class.
TaskUnsupervised$new( id, task_type = "unsupervised", backend, label = NA_character_, extra_args = list() )
id(character(1))
Identifier for the new instance.
task_type(character(1))
Type of task, e.g. "regr" or "classif".
Must be an element of mlr_reflections$task_types$type.
backend(DataBackend)
Either a DataBackend, or any object which is convertible to a DataBackend with as_data_backend().
E.g., a data.frame() will be converted to a DataBackendDataTable.
label(character(1))
Label for the new instance.
extra_args(named list())
Named list of constructor arguments, required for converting task types
via convert_task().
TaskUnsupervised$clone()The objects of this class are cloneable with this method.
TaskUnsupervised$clone(deep = FALSE)
deepWhether to make a deep clone.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html
Package mlr3data for more toy tasks.
Package mlr3oml for downloading tasks from https://www.openml.org.
Package mlr3viz for some generic visualizations.
Dictionary of Tasks: mlr_tasks
as.data.table(mlr_tasks) for a table of available Tasks in the running session (depending on the loaded packages).
mlr3fselect and mlr3filters for feature selection and feature filtering.
Extension packages for additional task types:
Unsupervised clustering: mlr3cluster
Probabilistic supervised regression and survival analysis: https://mlr3proba.mlr-org.com/.
Other Task:
Task,
TaskClassif,
TaskRegr,
TaskSupervised,
california_housing,
mlr_tasks,
mlr_tasks_breast_cancer,
mlr_tasks_german_credit,
mlr_tasks_iris,
mlr_tasks_mtcars,
mlr_tasks_penguins,
mlr_tasks_pima,
mlr_tasks_sonar,
mlr_tasks_spam,
mlr_tasks_wine,
mlr_tasks_zoo
TaskUnsupervised$new("penguins", task_type = "unsupervised", backend = palmerpenguins::penguins)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.