A LearnerClassif for a classification tree implemented in rpart::rpart() in package rpart.
Parameter xval is set to 0 in order to save some computation time.
This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():
mlr_learners$get("classif.rpart")
lrn("classif.rpart")
mlr3::Learner -> mlr3::LearnerClassif -> LearnerClassifRpart
new()Creates a new instance of this R6 class.
LearnerClassifRpart$new()
importance()The importance scores are extracted from the model slot variable.importance.
LearnerClassifRpart$importance()
Named numeric().
selected_features()Selected features are extracted from the model slot frame$var.
LearnerClassifRpart$selected_features()
character().
clone()The objects of this class are cloneable with this method.
LearnerClassifRpart$clone(deep = FALSE)
deepWhether to make a deep clone.
mlr3breiman_1984
Dictionary of Learners: mlr_learners
as.data.table(mlr_learners) for a complete table of all (also dynamically created) Learner implementations.
Other Learner:
LearnerClassif,
LearnerRegr,
Learner,
mlr_learners_classif.debug,
mlr_learners_classif.featureless,
mlr_learners_regr.featureless,
mlr_learners_regr.rpart,
mlr_learners