| mlr_measures_classif.auc | R Documentation |
Measure to compare true observed labels with predicted probabilities in binary classification tasks.
Computes the area under the Receiver Operator Characteristic (ROC) curve. The AUC can be interpreted as the probability that a randomly chosen positive observation has a higher predicted probability than a randomly chosen negative observation.
For n^+ positive and n^- negative observations with R_i^+ the rank of the
i-th positive observation's predicted probability (average ranks for ties), the AUC
is estimated as
\widehat{\operatorname{AUC}} = \frac{1}{n^+ n^-} \left( \sum_{i=1}^{n^+} R_i^+ \; - \; \frac{n^+(n^+ + 1)}{2} \right).
If sample_weights are provided, let w_i^+ be the weight of the i-th positive observation with
predicted probability p_i^+, W^+ = \sum_i w_i^+, and W^- the total weight of the
negative observations. Define the weighted Mann-Whitney contribution of positive observation i as
U_i^w = W_{< p_i^+}^- + \tfrac{1}{2} W_{= p_i^+}^-,
i.e. the total weight of negative observations with a smaller predicted probability plus half the weight
of negatives tied with p_i^+. The weighted AUC is then
\widehat{\operatorname{AUC}}_w = \frac{1}{W^+ W^-} \sum_{i=1}^{n^+} w_i^+ U_i^w.
This measure is undefined if the true values are either all positive or all negative.
This Measure can be instantiated via the dictionary mlr_measures or with the associated sugar function msr():
mlr_measures$get("classif.auc")
msr("classif.auc")
Empty ParamSet
Type: "binary"
Range: [0, 1]
Minimize: FALSE
Required prediction: prob
The score function calls mlr3measures::auc() from package mlr3measures.
If the measure is undefined for the input, NaN is returned.
This can be customized by setting the field na_value.
Dictionary of Measures: mlr_measures
as.data.table(mlr_measures) for a complete table of all (also dynamically created) Measure implementations.
Other classification measures:
mlr_measures_classif.acc,
mlr_measures_classif.bacc,
mlr_measures_classif.bbrier,
mlr_measures_classif.ce,
mlr_measures_classif.costs,
mlr_measures_classif.dor,
mlr_measures_classif.fbeta,
mlr_measures_classif.fdr,
mlr_measures_classif.fn,
mlr_measures_classif.fnr,
mlr_measures_classif.fomr,
mlr_measures_classif.fp,
mlr_measures_classif.fpr,
mlr_measures_classif.logloss,
mlr_measures_classif.mauc_au1p,
mlr_measures_classif.mauc_au1u,
mlr_measures_classif.mauc_aunp,
mlr_measures_classif.mauc_aunu,
mlr_measures_classif.mauc_mu,
mlr_measures_classif.mbrier,
mlr_measures_classif.mcc,
mlr_measures_classif.npv,
mlr_measures_classif.ppv,
mlr_measures_classif.prauc,
mlr_measures_classif.precision,
mlr_measures_classif.recall,
mlr_measures_classif.sensitivity,
mlr_measures_classif.specificity,
mlr_measures_classif.tn,
mlr_measures_classif.tnr,
mlr_measures_classif.tp,
mlr_measures_classif.tpr
Other binary classification measures:
mlr_measures_classif.bbrier,
mlr_measures_classif.dor,
mlr_measures_classif.fbeta,
mlr_measures_classif.fdr,
mlr_measures_classif.fn,
mlr_measures_classif.fnr,
mlr_measures_classif.fomr,
mlr_measures_classif.fp,
mlr_measures_classif.fpr,
mlr_measures_classif.npv,
mlr_measures_classif.ppv,
mlr_measures_classif.prauc,
mlr_measures_classif.precision,
mlr_measures_classif.recall,
mlr_measures_classif.sensitivity,
mlr_measures_classif.specificity,
mlr_measures_classif.tn,
mlr_measures_classif.tnr,
mlr_measures_classif.tp,
mlr_measures_classif.tpr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.