mlr_task_generators_simplex: Simplex Classification Task Generator

mlr_task_generators_simplexR Documentation

Simplex Classification Task Generator

Description

A TaskGenerator for the simplex task in mlbench::mlbench.simplex().

Note that the generator implemented in mlbench returns fewer samples than requested.

Dictionary

This TaskGenerator can be instantiated via the dictionary mlr_task_generators or with the associated sugar function tgen():

mlr_task_generators$get("simplex")
tgen("simplex")

Parameters

Id Type Default Levels Range
center logical TRUE TRUE, FALSE -
d integer 3 [1, \infty)
sd numeric 0.1 [0, \infty)
sides integer 1 [1, \infty)

Super class

TaskGenerator -> TaskGeneratorSimplex

Methods

Public methods

Inherited methods

TaskGeneratorSimplex$new()

Creates a new instance of this R6 class.

Usage
TaskGeneratorSimplex$new()

TaskGeneratorSimplex$plot()

Creates a simple plot of generated data.

Usage
TaskGeneratorSimplex$plot(n = 200L, pch = 19L, ...)
Arguments
n

(integer(1))
Number of samples to draw for the plot. Default is 200.

pch

(integer(1))
Point char. Passed to plot().

...

(any)
Additional arguments passed to plot().


TaskGeneratorSimplex$clone()

The objects of this class are cloneable with this method.

Usage
TaskGeneratorSimplex$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

  • Dictionary of TaskGenerators: mlr_task_generators

  • as.data.table(mlr_task_generators) for a table of available TaskGenerators in the running session (depending on the loaded packages).

  • Extension packages for additional task types:

    • mlr3proba for probabilistic supervised regression and survival analysis.

    • mlr3cluster for unsupervised clustering.

Other TaskGenerator: TaskGenerator, mlr_task_generators, mlr_task_generators_2dnormals, mlr_task_generators_cassini, mlr_task_generators_circle, mlr_task_generators_friedman1, mlr_task_generators_moons, mlr_task_generators_peak, mlr_task_generators_smiley, mlr_task_generators_spirals, mlr_task_generators_xor

Examples

generator = tgen("simplex")
plot(generator, n = 200)

task = generator$generate(200)
str(task$data())

mlr3 documentation built on June 11, 2026, 5:08 p.m.