This object wraps the predictions returned by a learner of class LearnerRegr, i.e.
the predicted response and standard error.
Additionally, probability distributions implemented in distr6 are supported.
(numeric())
Vector of numeric response values.
One element for each observation in the test set.
se
(numeric())
Numeric vector of predicted standard errors.
One element for each observation in the test set.
distr
(distr6::VectorDistribution)
VectorDistribution from distr6.
Each individual distribution in the vector represents the random variable 'survival time'
for an individual observation.
check
(logical(1))
If TRUE, performs some argument checks and predict type conversions.