| mlr_task_generators_simplex | R Documentation |
A TaskGenerator for the simplex task in mlbench::mlbench.simplex().
Note that the generator implemented in mlbench returns fewer samples than requested.
This TaskGenerator can be instantiated via the dictionary mlr_task_generators or with the associated sugar function tgen():
mlr_task_generators$get("simplex")
tgen("simplex")
| Id | Type | Default | Levels | Range |
| center | logical | TRUE | TRUE, FALSE | - |
| d | integer | 3 | [1, \infty) |
|
| sd | numeric | 0.1 | [0, \infty) |
|
| sides | integer | 1 | [1, \infty) |
|
TaskGenerator -> TaskGeneratorSimplex
TaskGeneratorSimplex$new()Creates a new instance of this R6 class.
TaskGeneratorSimplex$new()
TaskGeneratorSimplex$plot()Creates a simple plot of generated data.
TaskGeneratorSimplex$plot(n = 200L, pch = 19L, ...)
n(integer(1))
Number of samples to draw for the plot. Default is 200.
pch(integer(1))
Point char. Passed to plot().
...(any)
Additional arguments passed to plot().
TaskGeneratorSimplex$clone()The objects of this class are cloneable with this method.
TaskGeneratorSimplex$clone(deep = FALSE)
deepWhether to make a deep clone.
Dictionary of TaskGenerators: mlr_task_generators
as.data.table(mlr_task_generators) for a table of available TaskGenerators in the running session (depending on the loaded packages).
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
Other TaskGenerator:
TaskGenerator,
mlr_task_generators,
mlr_task_generators_2dnormals,
mlr_task_generators_cassini,
mlr_task_generators_circle,
mlr_task_generators_friedman1,
mlr_task_generators_moons,
mlr_task_generators_peak,
mlr_task_generators_smiley,
mlr_task_generators_spirals,
mlr_task_generators_xor
generator = tgen("simplex")
plot(generator, n = 200)
task = generator$generate(200)
str(task$data())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.